------------------------------------------------------------------------------
--
--  Xilinx, Inc. 2002                 www.xilinx.com
--
--  XAPP 224 - Data Recovery
--
------------------------------------------------------------------------------
--
--  File name :       top_ve.vhd
--
--  Description :     Generic top level file to use data recovery module in a VirtexE,
-- 		      uses one dcm to generate two 90 degree phased clocks at up to 160 MHz.
--
--  Date - revision : December 6th 2004 - v 2.3
--
--  Author :          NJS
--
--  Contact : e-mail  hotline@xilinx.com
--            phone   + 1 800 255 7778 
--
--  Disclaimer: LIMITED WARRANTY AND DISCLAMER. These designs are
--              provided to you "as is". Xilinx and its licensors make and you
--              receive no warranties or conditions, express, implied,
--              statutory or otherwise, and Xilinx specifically disclaims any
--              implied warranties of merchantability, non-infringement,or
--              fitness for a particular purpose. Xilinx does not warrant that
--              the functions contained in these designs will meet your
--              requirements, or that the operation of these designs will be
--              uninterrupted or error free, or that defects in the Designs
--              will be corrected. Furthermore, Xilinx does not warrantor
--              make any representations regarding use or the results of the
--              use of the designs in terms of correctness, accuracy,
--              reliability, or otherwise.
--
--              LIMITATION OF LIABILITY. In no event will Xilinx or its
--              licensors be liable for any loss of data, lost profits,cost
--              or procurement of substitute goods or services, or for any
--              special, incidental, consequential, or indirect damages
--              arising from the use or operation of the designs or
--              accompanying documentation, however caused and on any theory
--              of liability. This limitation will apply even if Xilinx
--              has been advised of the possibility of such damage. This
--              limitation shall apply not-withstanding the failure of the
--              essential purpose of any limited remedies herein.
--
--  Copyright  2002 Xilinx, Inc.
--  All rights reserved
--
------------------------------------------------------------------------------
--
library IEEE;
use IEEE.std_logic_1164.all;

library unisim ;
use unisim.vcomponents.all ;

entity top_ve is port (
	clkin 	: in std_logic;			-- clock input
	rstin 	: in std_logic;			-- reset input
	datain 	: in std_logic;			-- data input
	dummy 	: out std_logic_vector(1 downto 0);	-- dummy output for recovered data
	dvalid 	: out std_logic_vector(1 downto 0);	-- recovered data valid when high
	locked	: out std_logic); 		-- DLL locked
end top_ve;

architecture arch_top_ve of top_ve is

-- Data recovery module
component data_recovery_virtexe port (
	clk 	: in std_logic;
	clk90 	: in std_logic;
	data 	: in std_logic;
	rst 	: in std_logic;
	sdata 	: out std_logic_vector(1 downto 0) ;
	dv 	: out std_logic_vector(1 downto 0)) ; 
end component;

signal clk   	: std_logic;
signal clkdllo	: std_logic;
signal clkint	: std_logic;
signal clk90	: std_logic;
signal clk90dllo : std_logic;
signal dummyint : std_logic_vector(1 downto 0) ;
signal dvalidint: std_logic_vector(1 downto 0) ;

begin

dll1 : clkdll port map(
	clkin 	=> clkint,
	clkfb 	=> clk,
	rst   	=> rstin,
	clk0  	=> clkdllo,
	clk90  	=> clk90dllo,
	clk180 	=> open,
	clk270 	=> open,
	clk2X 	=> open,
	clkDV 	=> open,
	locked	=> locked);
	
ibufg1 : ibufg port map(i => clkin, o => clkint );

bufg1  : bufg  port map(i => clkdllo, o => clk );
bufg2  : bufg  port map(i => clk90dllo, o => clk90 );

drmodule : data_recovery_virtexe port map(
	data 	=> datain,
	rst   	=> rstin,
	clk   	=> clk,
	clk90 	=> clk90,
	sdata 	=> dummyint,
	dv 	=> dvalidint );
		
process (clk, rstin)
begin
if rstin = '1' then
	dummy <= "00" ;
	dvalid <= "00" ;
elsif clk'event and clk = '1' then
	dummy <= dummyint ;
	dvalid <= dvalidint ;
end if ;
end process ;
end arch_top_ve;


